summaryrefslogtreecommitdiff
path: root/include/IAmRouting.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/IAmRouting.h')
-rw-r--r--include/IAmRouting.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/include/IAmRouting.h b/include/IAmRouting.h
index 28e8ac9..c58c721 100644
--- a/include/IAmRouting.h
+++ b/include/IAmRouting.h
@@ -418,14 +418,15 @@ public:
* Forward hand-over of a connection meant to survive AM shutdown
* in routing-side application
*
* @param handle: composite identifier used to map the response
* @param route: names of involved sources and sinks including intermediate gateways
* @param state: either stable CS_CONNECTED, CS_DISCONNECTED, CS_SUSPENDED
* or transient CS_CONNECTING, CS_DISCONNECTING
*
* @return success indicator as obtained from the plugins, e.g E_OK or E_COMMUNICATION
*/
- virtual am_Error_e asyncTransferConnection(const am_Handle_s handle
+ virtual am_Error_e asyncTransferConnection(const am_Handle_s handle, am_domainID_t domainID
, const std::vector<std::pair<std::string, std::string>> &route
, am_ConnectionState_e state)
{
@@ -418,14 +418,15 @@ public:
* in routing-side application
*
- * @param handle: composite identifier used to map the response
- * @param route: names of involved sources and sinks including intermediate gateways
- * @param state: either stable CS_CONNECTED, CS_DISCONNECTED, CS_SUSPENDED
- * or transient CS_CONNECTING, CS_DISCONNECTING
+ * @param handle: composite identifier used to map the response
+ * @param domainID: target domain for this offering
+ * @param route: names of involved sources and sinks including intermediate gateways
+ * @param state: either stable CS_CONNECTED, CS_DISCONNECTED, CS_SUSPENDED
+ * or transient CS_CONNECTING, CS_DISCONNECTING
*
* @return success indicator as obtained from the plugins, e.g E_OK or E_COMMUNICATION